Author: Napier Lopez
Description: After rumors started spreading earlier today that Blackberry was in the midst of talks to be acquired by Samsung – causing its stocks to rise suddenly by 29 percent – the company…
Date: 2015-01-14T23:57:29+01:00

- Latest
- Popular

Facebook’s third Q&A: Zuckerberg thinks existing wearables are goofy, talks future of Web

# BlackBerry denies Samsung buyout rumors

Share Tweet HN
269
Shares
0
Comments
Facebook’s third Q&A: Zuckerberg thinks existing wearables are goofy, talks future of Web
Save to ▾

- Buffer
- Pocket
  Pro
- Evernote
  Pro
- PDF
  Pro

Napier Lopez
14 January '15, 11:57pm
Follow

After rumors started spreading earlier today that Blackberry was in the midst of talks to be acquired by Samsung – causing its stocks to rise suddenly by 29 percent – the company has offered an official comment: it “has not engaged with Samsung with respect to any possible offer to purchase BlackBerry.”

Blackberry then goes on to say its policy is not to comment on rumors – how nice of them to make an exception – and will talk no further about the matter.

Here’s the full statement:

> BlackBerry Limited (NASDAQ:BBRY)(TSX:BB) (“BlackBerry”) is aware of certain press reports published today with respect to a possible offer by Samsung to purchase BlackBerry. BlackBerry has not engaged in discussions with Samsung with respect to any possible offer to purchase BlackBerry. BlackBerry’s policy is not to comment on rumors or speculation, and accordingly it does not intend to comment further.

In all, it looks like the rumors amounted to no more than speculation; we’ll update if we hear more.

➤ BlackBerry responds to media report [BlackBerry]

Show comments
Facebook’s third Q&A: Zuckerberg thinks existing wearables are goofy, talks future of Web

#### Discussion

### Related stories

## Facebook’s third Q&A: Mark Zuckerberg thinks existing wearables are goofy and more

## Facebook launches Facebook At Work… but you probably won’t be able to try it yet

## Google Translate gets real-time voice and sign translations on iOS and Android

## Obama plans executive action to speed up US broadband

## Google’s new Classroom app opens its doors on Android and iOS

## Firefox 35 brings improved cross-browser video chat and better performance

×
Don't miss this:
Facebook’s third Q&A: Zuckerberg thinks existing wearables are goofy, talks future of Web
.